using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Drawing.Printing;
using System.Data.SqlClient;

namespace ProgramDB
{
    public partial class RejestryVAT : Form
    {
        private DataGridViewPrinter MyDataGridViewPrinter;
        private decimal ptuC;
        private decimal ptuD;
        private string[] stawki = WprowadzanieDokumentow.Stawki;
        private string[] stawkiRyczalt = WprowadzanieDokumentow.StawkiRyczalt;
        public RejestryVAT()
        {
            InitializeComponent();
        }

        private int WybranyWiersz
        {
            get
            {
                return ownDataGridView1.SelectedRows[0].Index; // return selected row
            }
        }

        public void FiltrRejestryVAT(params object[] text)
        { 
            dataSet1.Clear();

            sqlCommand1.Parameters["@contractorCheck"].Value = text[0];
            sqlCommand1.Parameters["@contractor"].Value = text[1]; // MethodsClass.ExeStoredProcedureRetInt("uspGetKontrahenciID", "NazwaSkrocona", text[1]);
            sqlCommand1.Parameters["@monthCheck"].Value = text[2];
            if (text[3].ToString() != "")
                sqlCommand1.Parameters["@month"].Value = MethodsClass.DictionaryMonthStringToInt(text[3].ToString()); // set number of month
            else
                sqlCommand1.Parameters["@month"].Value = 0;

            SqlDataAdapter adapter = new SqlDataAdapter(sqlCommand1);
            adapter.Fill(dataSet1, "RejestrVATView");
            ownDataGridView1.DataSource = dataSet1.Tables["RejestrVATView"];

            ownDataGridView1.Columns[0].Visible = false;
            ownDataGridView1.DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleCenter;
            ownDataGridView1.ColumnHeadersDefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleCenter;
        }

        private void RejestryVAT_Load(object sender, EventArgs e)
        {
            if (MethodsClass.ExeFunctionRetBool("dbo.IfPKPiR()"))
            {
                this.sdaGetRejestrVAT.Fill(this.dataSet1, "RejestrVATView");
                ownDataGridView1.DataSource = dataSet1;
                ownDataGridView1.DataMember = "RejestrVATView";
            }
            else
            {
                this.sdaGetRejestrVATRyczalt.Fill(this.dataSet1, "RejestrVATRyczaltView");
                ownDataGridView1.DataSource = dataSet1;
                ownDataGridView1.DataMember = "RejestrVATRyczaltView";
            }
            ownDataGridView1.Columns["WprowadzanieDokumentowID"].Visible = false;
            ptuC = MethodsClass.ExeStoredProcedureRetDecimal("uspGetPTUC");
            ptuD = MethodsClass.ExeStoredProcedureRetDecimal("uspGetPTUD");
            ownDataGridView1.Columns["StawkaPTUCNetto"].HeaderText = "Netto " + ((ptuC - Math.Floor(ptuC)) == 0 ? Math.Round(ptuC) : ptuC).ToString() + "%";
            ownDataGridView1.Columns["StawkaPTUCVAT"].HeaderText = "VAT " + ((ptuC - Math.Floor(ptuC)) == 0 ? Math.Round(ptuC) : ptuC).ToString() + "%";
            ownDataGridView1.Columns["StawkaPTUDNetto"].HeaderText = "Netto " + ((ptuD - Math.Floor(ptuD)) == 0 ? Math.Round(ptuD) : ptuD).ToString() + "%";
            ownDataGridView1.Columns["StawkaPTUDVAT"].HeaderText = "VAT " + ((ptuD - Math.Floor(ptuD)) == 0 ? Math.Round(ptuD) : ptuD).ToString() + "%";
            ownDataGridView1.Columns["Miesic zaliczenia do ewidencji VAT"].Width += 10;

            ownDataGridView1.ColumnHeadersDefaultCellStyle.Font = new Font("Tahoma", 9, FontStyle.Bold, GraphicsUnit.Point);
            ownDataGridView1.ColumnHeadersDefaultCellStyle.BackColor = SystemColors.ControlDark;
            ownDataGridView1.ColumnHeadersBorderStyle = DataGridViewHeaderBorderStyle.Single;
            ownDataGridView1.DefaultCellStyle.Font = new Font("Tahoma", 8, FontStyle.Regular, GraphicsUnit.Point);
            ownDataGridView1.AlternatingRowsDefaultCellStyle.BackColor = SystemColors.ControlLight;
            ownDataGridView1.CellBorderStyle = DataGridViewCellBorderStyle.Single;
            ownDataGridView1.GridColor = SystemColors.ControlDarkDark;
            ownDataGridView1.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
            ownDataGridView1.DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleCenter;
            ownDataGridView1.ColumnHeadersDefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleCenter;
        } 

        private void Drukuj_Click(object sender, EventArgs e)
        {
            if (SetupThePrinting())
                printDocument1.Print();
        }

        private void Filtry_Click(object sender, EventArgs e)
        {
            WybierzFiltrRejestryVAT wybierzFiltrRejestryVAT = new WybierzFiltrRejestryVAT(this);
            if (wybierzFiltrRejestryVAT.ShowDialog() == DialogResult.OK)
                wybierzFiltrRejestryVAT.Close();
        }

        private void podgladWydruku_Click(object sender, EventArgs e)
        {
            if (SetupThePrinting())
            {
                PrintPreviewDialog MyPrintPreviewDialog = new PrintPreviewDialog();
                MyPrintPreviewDialog.Document = printDocument1;
                MyPrintPreviewDialog.ShowDialog();
            }
        }

        private void printDocument1_PrintPage(object sender, System.Drawing.Printing.PrintPageEventArgs e)
        {
            bool more = MyDataGridViewPrinter.DrawDataGridView(e.Graphics);
            if (more == true)
                e.HasMorePages = true;
        }

        private bool SetupThePrinting()
        {
            PrintDialog MyPrintDialog = new PrintDialog();
            MyPrintDialog.AllowCurrentPage = false;
            MyPrintDialog.AllowPrintToFile = false;
            MyPrintDialog.AllowSelection = false;
            MyPrintDialog.AllowSomePages = false;
            MyPrintDialog.PrintToFile = false;
            MyPrintDialog.ShowHelp = false;
            MyPrintDialog.ShowNetwork = false;

            if (MyPrintDialog.ShowDialog() != DialogResult.OK)
                return false;

            printDocument1.DocumentName = "PrintDocument";
            printDocument1.PrinterSettings = MyPrintDialog.PrinterSettings;
            printDocument1.DefaultPageSettings = MyPrintDialog.PrinterSettings.DefaultPageSettings;
            printDocument1.DefaultPageSettings.Margins = new Margins(40, 40, 40, 40);

            if (MessageBox.Show("Chcesz eby tytu tabeli by wyrodkowany?", "Pytanie", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
                MyDataGridViewPrinter = new DataGridViewPrinter(ownDataGridView1, printDocument1, true, true, "Rejestry VAT", new Font("Tahoma", 18, FontStyle.Bold, GraphicsUnit.Point), Color.Black, true);
            else
                MyDataGridViewPrinter = new DataGridViewPrinter(ownDataGridView1, printDocument1, false, true, "Rejestry VAT", new Font("Tahoma", 18, FontStyle.Bold, GraphicsUnit.Point), Color.Black, true);

            return true;
        }

        private void eksport_Click(object sender, EventArgs e)
        {
            ExportToExcel(ownDataGridView1);
        }

        public void ExportToExcel(DataGridView grid)
        {
            Microsoft.Office.Interop.Excel.ApplicationClass excelSheet = new Microsoft.Office.Interop.Excel.ApplicationClass();
            excelSheet.Application.Workbooks.Add(true);
            int columnIndex = 0;
            //Columns Heading of Datagridview     
            foreach (DataGridViewColumn column in grid.Columns)
            {
                columnIndex++;
                if (!column.HeaderText.Equals("WprowadzanieDokumentowID")) // write column which I don't want to see in the excel 
                    excelSheet.Cells[1, columnIndex] = column.HeaderText;
                else
                    columnIndex--;
            }
            int rowIndex = 0;
            //get all rows by column wise 
            foreach (DataGridViewRow row in grid.Rows)
            {
                rowIndex++;
                columnIndex = 0;
                foreach (DataGridViewColumn column in grid.Columns)
                {
                    columnIndex++;
                    if (!column.HeaderText.Equals("WprowadzanieDokumentowID")) // write column which I don't want to see in the excel 
                        excelSheet.Cells[rowIndex + 1, columnIndex] = row.Cells[column.Name].FormattedValue;
                    else
                        columnIndex--;
                }
            }
            excelSheet.Visible = true;
            Microsoft.Office.Interop.Excel.Worksheet workSheet = (Microsoft.Office.Interop.Excel.Worksheet)excelSheet.ActiveSheet;
        }
    }
}